ElfFile class

Constructors

ElfFile(Uint8List bytes)

Properties

bytes Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
relocationSections List<ElfSection>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sections List<ElfSection>
final
symtab ElfSection?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readRelocations(ElfSection section) List<ElfRelocation>
readSymbols(ElfSection section) List<ElfSymbol>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited