ElfSection class

Constructors

ElfSection({required int index, required String name, required int type, required int offset, required int size, required int link, required int info, required int entrySize})
const

Properties

entrySize int
final
hashCode int
The hash code for this object.
no setterinherited
index int
final
info int
final
final
name String
final
offset int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final
type int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

typeRel → const int
typeSymtab → const int