FastFap class

Constructors

FastFap()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildSections(File fap) List<FastFapSection>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

gnuSymHash(String name) int

Constants

fastRelPrefix → const String
relPrefix → const String
version → const int