FlipperImage class

Constructors

FlipperImage({required int width, required int height, required Uint8List xbm, required Uint8List data})
const

Properties

data Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
height int
final
isCompressed bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
final
xbm Uint8List
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited