IconAssetsCompiler class

Constructors

IconAssetsCompiler({IconCodec codec = const IconCodec()})
const

Properties

codec IconCodec
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compile({required Directory inputDir, required Directory outputDir, required String bundleName}) CompiledIcons
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

frameRateFile → const String
maxImageHeight → const int
maxImageWidth → const int
supportedFormats → const List<String>