UfbtPaths class

Constructors

UfbtPaths({required String home, String? toolchainPath})

Properties

currentSdkDir Directory
no setter
downloadDir Directory
no setter
fbtenvCmd File
no setter
fbtenvScript File
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdkScriptsDir Directory
no setter
stateDir Directory
final
stateFile File
no setter
no setter
toolchainDir Directory
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toolchainArchDir(String archDir) Directory
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

defaultUfbtHome([Map<String, String>? environment]) String
join(String a, String b, [String? c]) String
loadEnvFile([String? directory]) Map<String, String>
resolve({String? projectDir, Map<String, String>? environment}) UfbtPaths

Constants

envFileName → const String
stateFileName → const String
toolchainSubdir → const String