UfbtBuildEvent class

Inheritance

Constructors

UfbtBuildEvent({required DateTime time, required String tag, required String value, required List<String> details, required String formatted})
const

Properties

details List<String>
final
formatted String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
final
time DateTime
finalinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited