UfbtProgressEvent class

Inheritance

Constructors

UfbtProgressEvent({required DateTime time, required UfbtProgress progress})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
progress UfbtProgress
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time DateTime
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited