UfbtLogFormat class abstract final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

build(String tag, String value, List<String> details) String
message(DateTime time, UfbtLogLevel level, String message) String
percent(double value) String
progressBar(UfbtProgress progress, {int width = defaultBarWidth}) String
timestamp(DateTime time) String

Constants

barChar → const String
defaultBarWidth → const int