UfbtLogLevel enum
Values
- debug → const UfbtLogLevel
-
const UfbtLogLevel(10) - info → const UfbtLogLevel
-
const UfbtLogLevel(20) - warning → const UfbtLogLevel
-
const UfbtLogLevel(30) - error → const UfbtLogLevel
-
const UfbtLogLevel(40) - critical → const UfbtLogLevel
-
const UfbtLogLevel(50)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- letter → String
-
no setter
- levelName → String
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UfbtLogLevel> - A constant List of the values in this enum, in order of their declaration.