UfbtProgressTask class

Properties

hashCode int
The hash code for this object.
no setterinherited
progress UfbtProgress
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

advance([int delta = 1]) → void
fail({String? message}) → void
finish({String? message}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update({int? current, int? total, String? message}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited