UfbtProgress class
Constructors
- UfbtProgress({required String id, required String title, required UfbtProgressState state, required int current, int? total, String? message})
-
const
Properties
- current → int
-
final
- fraction → double?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- indeterminate → bool
-
no setter
- isDone → bool
-
no setter
- message → String?
-
final
- percent → double?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → UfbtProgressState
-
final
- title → String
-
final
- total → int?
-
final
Methods
-
copyWith(
{UfbtProgressState? state, int? current, int? total, String? message}) → UfbtProgress -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited