SdkDeployTask class

Constructors

SdkDeployTask({String? hwTarget, bool force = false, String? mode, Map<String, String>? params})

Properties

force bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hwTarget String?
getter/setter pair
mode String?
getter/setter pair
params Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
updateFrom(SdkDeployTask other) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

branch({required String branch, String hwTarget = defaultHwTarget, String? indexUrl, bool force = false}) SdkDeployTask
channel({UfbtUpdateChannel channel = UfbtUpdateChannel.release, String hwTarget = defaultHwTarget, String? indexUrl, bool force = false}) SdkDeployTask
defaults() SdkDeployTask
fromState(Map<String, dynamic> state) SdkDeployTask
local({required String filePath, required String hwTarget, bool force = false}) SdkDeployTask
url({required String url, required String hwTarget, bool force = false}) SdkDeployTask

Constants

defaultHwTarget → const String