UfbtUpdateChannel enum

Inheritance
Available extensions

Values

dev → const UfbtUpdateChannel
const UfbtUpdateChannel('development')
rc → const UfbtUpdateChannel
const UfbtUpdateChannel('release-candidate')
release → const UfbtUpdateChannel
const UfbtUpdateChannel('release')

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
index int
A numeric identifier for the enumerated value.
no setterinherited
key String
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
pythonName String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

byKey(String key) UfbtUpdateChannel

Constants

values → const List<UfbtUpdateChannel>
A constant List of the values in this enum, in order of their declaration.