BranchSdkLoader class

Inheritance

Constructors

BranchSdkLoader({required UfbtLogger logger, required UfbtFileFetcher fetcher, required Directory downloadDir, required String branch, String? branchRootUrl})

Properties

branch String
final
branchRoot String
final
branchUrl String
no setter
downloadDir Directory
finalinherited
fetcher UfbtFileFetcher
finalinherited
hashCode int
The hash code for this object.
no setterinherited
logger UfbtLogger
finalinherited
metadata Map<String, String>
no setteroverride
modeKey String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getSdkComponent(String target) Future<File>
override
load() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

loaderModeKey → const String
updateServerBranchRoot → const String