UpdateChannelSdkLoader class

Inheritance

Constructors

UpdateChannelSdkLoader({required UfbtLogger logger, required UfbtFileFetcher fetcher, required Directory downloadDir, required UfbtUpdateChannel channel, String? jsonIndexUrl})

Properties

channel UfbtUpdateChannel
final
downloadDir Directory
finalinherited
fetcher UfbtFileFetcher
finalinherited
hashCode int
The hash code for this object.
no setterinherited
jsonIndexUrl String
final
logger UfbtLogger
finalinherited
metadata Map<String, String>
no setteroverride
modeKey String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
versionInfo UfbtIndexVersion
no setter

Methods

getSdkComponent(String target) Future<File>
override
load() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

loaderModeKey → const String
officialIndexUrl → const String