UfbtUpdateCheck class

Constructors

UfbtUpdateCheck({required String? currentVersion, required String latestVersion, required String target})
const

Properties

currentVersion String?
final
hashCode int
The hash code for this object.
no setterinherited
latestVersion String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target String
final
updateAvailable bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited