FapBuildResult class
Constructors
-
FapBuildResult({required bool success, required FlipperApplication? app, File? fap, File? debugElf, List<
String> unresolvedSymbols = const [], String? error, String? distPath}) -
const
Properties
- app → FlipperApplication?
-
final
- debugElf → File?
-
final
- distPath → String?
-
Where the artifact belongs on the SD card, relative to its root, the way
fbt lays out
dist_entries. Null for plugins embedded into their app.final - error → String?
-
final
- fap → File?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
final
-
unresolvedSymbols
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited