FapBuilder class
Constructors
- FapBuilder({required UfbtLogger logger, required UfbtPaths paths})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → UfbtLogger
-
final
- paths → UfbtPaths
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
{required Directory appDir, String? appid, Directory? outputDir}) → Future< FapBuildResult> -
buildAll(
{required Directory appDir, Directory? outputDir}) → Future< List< FapBuildResult> > -
Builds every app of the manifest, as fbt does: plugins become
.faland the ones markedfal_embeddedare packed into the assets of the app they belong to, so they have to be built first. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fileAssetsSection → const String
- metaSection → const String