UfbtLogger class
Constructors
- UfbtLogger({UfbtLogSink? sink, UfbtLogLevel level = UfbtLogLevel.info, DateTime clock()?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- level ↔ UfbtLogLevel
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verbose ↔ bool
-
getter/setter pair
Methods
-
addSink(
UfbtLogSink sink) → void -
build(
String tag, String value, {List< String> details = const []}) → void -
clearSinks(
) → void -
critical(
String message) → void -
debug(
String message) → void -
emit(
UfbtLogEvent event) → void -
error(
String message) → void -
info(
String message) → void -
isEnabledFor(
UfbtLogLevel level) → bool -
log(
UfbtLogLevel level, String message) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
progress(
String title, {int? total, String? id, UfbtProgressThrottle? throttle}) → UfbtProgressTask -
raw(
String text, {bool newline = true}) → void -
removeSink(
UfbtLogSink sink) → void -
toString(
) → String -
A string representation of this object.
inherited
-
warning(
String message) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited