UfbtFileType enum
Values
- sdkZip → const UfbtFileType
-
const UfbtFileType('sdk_zip') - libZip → const UfbtFileType
-
const UfbtFileType('lib_zip') - core2FirmwareTgz → const UfbtFileType
-
const UfbtFileType('core2_firmware_tgz') - resourcesTgz → const UfbtFileType
-
const UfbtFileType('resources_tgz') - scriptsTgz → const UfbtFileType
-
const UfbtFileType('scripts_tgz') - updateTgz → const UfbtFileType
-
const UfbtFileType('update_tgz') - firmwareElf → const UfbtFileType
-
const UfbtFileType('firmware_elf') - fullBin → const UfbtFileType
-
const UfbtFileType('full_bin') - fullDfu → const UfbtFileType
-
const UfbtFileType('full_dfu') - fullJson → const UfbtFileType
-
const UfbtFileType('full_json') - updaterBin → const UfbtFileType
-
const UfbtFileType('updater_bin') - updaterDfu → const UfbtFileType
-
const UfbtFileType('updater_dfu') - updaterElf → const UfbtFileType
-
const UfbtFileType('updater_elf') - updaterJson → const UfbtFileType
-
const UfbtFileType('updater_json')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UfbtFileType> - A constant List of the values in this enum, in order of their declaration.